==> vertx-rx-java-gen-3.9.2.redhat-00001-test-sources.jar: io/vertx/rxjava/codegen/testmodel/ConstantTCK.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava.codegen.testmodel;

import rx.Observable;
import rx.Single;
import io.vertx.rx.java.RxHelper;
import io.vertx.rx.java.WriteStreamSubscriber;
import io.vertx.rx.java.SingleOnSubscribeAdapter;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.codegen.testmodel.ConstantTCK.class)
public class ConstantTCK {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConstantTCK that = (ConstantTCK) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<ConstantTCK> __TYPE_ARG = new TypeArg<>(    obj -> new ConstantTCK((io.vertx.codegen.testmodel.ConstantTCK) obj),
    ConstantTCK::getDelegate
  );

  private final io.vertx.codegen.testmodel.ConstantTCK delegate;
  
  public ConstantTCK(io.vertx.codegen.testmodel.ConstantTCK delegate) {
    this.delegate = delegate;
  }

  public ConstantTCK(Object delegate) {
    this.delegate = (io.vertx.codegen.testmodel.ConstantTCK)delegate;
  }

  public io.vertx.codegen.testmodel.ConstantTCK getDelegate() {
    return delegate;
  }

  /**
   * Some doc.
   */
  public static final byte BYTE = io.vertx.codegen.testmodel.ConstantTCK.BYTE;
  public static final Byte BOXED_BYTE = io.vertx.codegen.testmodel.ConstantTCK.BOXED_BYTE;
  public static final short SHORT = io.vertx.codegen.testmodel.ConstantTCK.SHORT;
  public static final Short BOXED_SHORT = io.vertx.codegen.testmodel.ConstantTCK.BOXED_SHORT;
  public static final int INT = io.vertx.codegen.testmodel.ConstantTCK.INT;
  public static final Integer BOXED_INT = io.vertx.codegen.testmodel.ConstantTCK.BOXED_INT;
  public static final long LONG = io.vertx.codegen.testmodel.ConstantTCK.LONG;
  public static final Long BOXED_LONG = io.vertx.codegen.testmodel.ConstantTCK.BOXED_LONG;
  public static final float FLOAT = io.vertx.codegen.testmodel.ConstantTCK.FLOAT;
  public static final Float BOXED_FLOAT = io.vertx.codegen.testmodel.ConstantTCK.BOXED_FLOAT;
  public static final double DOUBLE = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE;
  public static final Double BOXED_DOUBLE = io.vertx.codegen.testmodel.ConstantTCK.BOXED_DOUBLE;
  public static final boolean BOOLEAN = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN;
  public static final Boolean BOXED_BOOLEAN = io.vertx.codegen.testmodel.ConstantTCK.BOXED_BOOLEAN;
  public static final char CHAR = io.vertx.codegen.testmodel.ConstantTCK.CHAR;
  public static final Character BOXED_CHAR = io.vertx.codegen.testmodel.ConstantTCK.BOXED_CHAR;
  public static final String STRING = io.vertx.codegen.testmodel.ConstantTCK.STRING;
  public static final io.vertx.rxjava.codegen.testmodel.RefedInterface1 VERTX_GEN = io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)io.vertx.codegen.testmodel.ConstantTCK.VERTX_GEN);
  public static final io.vertx.codegen.testmodel.TestDataObject DATA_OBJECT = io.vertx.codegen.testmodel.ConstantTCK.DATA_OBJECT;
  public static final JsonObject JSON_OBJECT = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT;
  public static final JsonArray JSON_ARRAY = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY;
  public static final io.vertx.codegen.testmodel.TestEnum ENUM = io.vertx.codegen.testmodel.ConstantTCK.ENUM;
  public static final java.lang.Throwable THROWABLE = io.vertx.codegen.testmodel.ConstantTCK.THROWABLE;
  public static final java.lang.Object OBJECT = (Object) io.vertx.codegen.testmodel.ConstantTCK.OBJECT;
  public static final io.vertx.rxjava.codegen.testmodel.RefedInterface1 NULLABLE_NON_NULL = io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)io.vertx.codegen.testmodel.ConstantTCK.NULLABLE_NON_NULL);
  public static final io.vertx.rxjava.codegen.testmodel.RefedInterface1 NULLABLE_NULL = io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)io.vertx.codegen.testmodel.ConstantTCK.NULLABLE_NULL);
  public static final List<Byte> BYTE_LIST = io.vertx.codegen.testmodel.ConstantTCK.BYTE_LIST;
  public static final List<Short> SHORT_LIST = io.vertx.codegen.testmodel.ConstantTCK.SHORT_LIST;
  public static final List<Integer> INT_LIST = io.vertx.codegen.testmodel.ConstantTCK.INT_LIST;
  public static final List<Long> LONG_LIST = io.vertx.codegen.testmodel.ConstantTCK.LONG_LIST;
  public static final List<Float> FLOAT_LIST = io.vertx.codegen.testmodel.ConstantTCK.FLOAT_LIST;
  public static final List<Double> DOUBLE_LIST = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE_LIST;
  public static final List<Boolean> BOOLEAN_LIST = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN_LIST;
  public static final List<Character> CHAR_LIST = io.vertx.codegen.testmodel.ConstantTCK.CHAR_LIST;
  public static final List<String> STRING_LIST = io.vertx.codegen.testmodel.ConstantTCK.STRING_LIST;
  public static final List<io.vertx.rxjava.codegen.testmodel.RefedInterface1> VERTX_GEN_LIST = io.vertx.codegen.testmodel.ConstantTCK.VERTX_GEN_LIST.stream().map(elt -> io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)elt)).collect(java.util.stream.Collectors.toList());
  public static final List<JsonObject> JSON_OBJECT_LIST = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT_LIST;
  public static final List<JsonArray> JSON_ARRAY_LIST = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY_LIST;
  public static final List<io.vertx.codegen.testmodel.TestDataObject> DATA_OBJECT_LIST = io.vertx.codegen.testmodel.ConstantTCK.DATA_OBJECT_LIST;
  public static final List<io.vertx.codegen.testmodel.TestEnum> ENUM_LIST = io.vertx.codegen.testmodel.ConstantTCK.ENUM_LIST;
  public static final Set<Byte> BYTE_SET = io.vertx.codegen.testmodel.ConstantTCK.BYTE_SET;
  public static final Set<Short> SHORT_SET = io.vertx.codegen.testmodel.ConstantTCK.SHORT_SET;
  public static final Set<Integer> INT_SET = io.vertx.codegen.testmodel.ConstantTCK.INT_SET;
  public static final Set<Long> LONG_SET = io.vertx.codegen.testmodel.ConstantTCK.LONG_SET;
  public static final Set<Float> FLOAT_SET = io.vertx.codegen.testmodel.ConstantTCK.FLOAT_SET;
  public static final Set<Double> DOUBLE_SET = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE_SET;
  public static final Set<Boolean> BOOLEAN_SET = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN_SET;
  public static final Set<Character> CHAR_SET = io.vertx.codegen.testmodel.ConstantTCK.CHAR_SET;
  public static final Set<String> STRING_SET = io.vertx.codegen.testmodel.ConstantTCK.STRING_SET;
  public static final Set<io.vertx.rxjava.codegen.testmodel.RefedInterface1> VERTX_GEN_SET = io.vertx.codegen.testmodel.ConstantTCK.VERTX_GEN_SET.stream().map(elt -> io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)elt)).collect(java.util.stream.Collectors.toSet());
  public static final Set<JsonObject> JSON_OBJECT_SET = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT_SET;
  public static final Set<JsonArray> JSON_ARRAY_SET = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY_SET;
  public static final Set<io.vertx.codegen.testmodel.TestDataObject> DATA_OBJECT_SET = io.vertx.codegen.testmodel.ConstantTCK.DATA_OBJECT_SET;
  public static final Set<io.vertx.codegen.testmodel.TestEnum> ENUM_SET = io.vertx.codegen.testmodel.ConstantTCK.ENUM_SET;
  public static final java.util.Map<String, Byte> BYTE_MAP = io.vertx.codegen.testmodel.ConstantTCK.BYTE_MAP;
  public static final java.util.Map<String, Short> SHORT_MAP = io.vertx.codegen.testmodel.ConstantTCK.SHORT_MAP;
  public static final java.util.Map<String, Integer> INT_MAP = io.vertx.codegen.testmodel.ConstantTCK.INT_MAP;
  public static final java.util.Map<String, Long> LONG_MAP = io.vertx.codegen.testmodel.ConstantTCK.LONG_MAP;
  public static final java.util.Map<String, Float> FLOAT_MAP = io.vertx.codegen.testmodel.ConstantTCK.FLOAT_MAP;
  public static final java.util.Map<String, Double> DOUBLE_MAP = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE_MAP;
  public static final java.util.Map<String, Boolean> BOOLEAN_MAP = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN_MAP;
  public static final java.util.Map<String, Character> CHAR_MAP = io.vertx.codegen.testmodel.ConstantTCK.CHAR_MAP;
  public static final java.util.Map<String, String> STRING_MAP = io.vertx.codegen.testmodel.ConstantTCK.STRING_MAP;
  public static final java.util.Map<String, JsonObject> JSON_OBJECT_MAP = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT_MAP;
  public static final java.util.Map<String, JsonArray> JSON_ARRAY_MAP = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY_MAP;
  public static ConstantTCK newInstance(io.vertx.codegen.testmodel.ConstantTCK arg) {
    return arg != null ? new ConstantTCK(arg) : null;
  }

}

==> vertx-rx-java-gen-4.0.0.redhat-00001-test-sources.jar: io/vertx/rxjava/codegen/testmodel/ConstantTCK.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava.codegen.testmodel;

import rx.Observable;
import rx.Single;
import io.vertx.rx.java.RxHelper;
import io.vertx.rx.java.WriteStreamSubscriber;
import io.vertx.rx.java.SingleOnSubscribeAdapter;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.codegen.testmodel.ConstantTCK.class)
public class ConstantTCK {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConstantTCK that = (ConstantTCK) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<ConstantTCK> __TYPE_ARG = new TypeArg<>(    obj -> new ConstantTCK((io.vertx.codegen.testmodel.ConstantTCK) obj),
    ConstantTCK::getDelegate
  );

  private final io.vertx.codegen.testmodel.ConstantTCK delegate;
  
  public ConstantTCK(io.vertx.codegen.testmodel.ConstantTCK delegate) {
    this.delegate = delegate;
  }

  public ConstantTCK(Object delegate) {
    this.delegate = (io.vertx.codegen.testmodel.ConstantTCK)delegate;
  }

  public io.vertx.codegen.testmodel.ConstantTCK getDelegate() {
    return delegate;
  }

  /**
   * Some doc.
   */
  public static final byte BYTE = io.vertx.codegen.testmodel.ConstantTCK.BYTE;
  public static final Byte BOXED_BYTE = io.vertx.codegen.testmodel.ConstantTCK.BOXED_BYTE;
  public static final short SHORT = io.vertx.codegen.testmodel.ConstantTCK.SHORT;
  public static final Short BOXED_SHORT = io.vertx.codegen.testmodel.ConstantTCK.BOXED_SHORT;
  public static final int INT = io.vertx.codegen.testmodel.ConstantTCK.INT;
  public static final Integer BOXED_INT = io.vertx.codegen.testmodel.ConstantTCK.BOXED_INT;
  public static final long LONG = io.vertx.codegen.testmodel.ConstantTCK.LONG;
  public static final Long BOXED_LONG = io.vertx.codegen.testmodel.ConstantTCK.BOXED_LONG;
  public static final float FLOAT = io.vertx.codegen.testmodel.ConstantTCK.FLOAT;
  public static final Float BOXED_FLOAT = io.vertx.codegen.testmodel.ConstantTCK.BOXED_FLOAT;
  public static final double DOUBLE = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE;
  public static final Double BOXED_DOUBLE = io.vertx.codegen.testmodel.ConstantTCK.BOXED_DOUBLE;
  public static final boolean BOOLEAN = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN;
  public static final Boolean BOXED_BOOLEAN = io.vertx.codegen.testmodel.ConstantTCK.BOXED_BOOLEAN;
  public static final char CHAR = io.vertx.codegen.testmodel.ConstantTCK.CHAR;
  public static final Character BOXED_CHAR = io.vertx.codegen.testmodel.ConstantTCK.BOXED_CHAR;
  public static final String STRING = io.vertx.codegen.testmodel.ConstantTCK.STRING;
  public static final io.vertx.rxjava.codegen.testmodel.RefedInterface1 VERTX_GEN = io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)io.vertx.codegen.testmodel.ConstantTCK.VERTX_GEN);
  public static final io.vertx.codegen.testmodel.TestDataObject DATA_OBJECT = io.vertx.codegen.testmodel.ConstantTCK.DATA_OBJECT;
  public static final JsonObject JSON_OBJECT = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT;
  public static final JsonArray JSON_ARRAY = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY;
  public static final io.vertx.codegen.testmodel.TestEnum ENUM = io.vertx.codegen.testmodel.ConstantTCK.ENUM;
  public static final java.lang.Throwable THROWABLE = io.vertx.codegen.testmodel.ConstantTCK.THROWABLE;
  public static final java.lang.Object OBJECT = (Object) io.vertx.codegen.testmodel.ConstantTCK.OBJECT;
  public static final io.vertx.rxjava.codegen.testmodel.RefedInterface1 NULLABLE_NON_NULL = io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)io.vertx.codegen.testmodel.ConstantTCK.NULLABLE_NON_NULL);
  public static final io.vertx.rxjava.codegen.testmodel.RefedInterface1 NULLABLE_NULL = io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)io.vertx.codegen.testmodel.ConstantTCK.NULLABLE_NULL);
  public static final List<Byte> BYTE_LIST = io.vertx.codegen.testmodel.ConstantTCK.BYTE_LIST;
  public static final List<Short> SHORT_LIST = io.vertx.codegen.testmodel.ConstantTCK.SHORT_LIST;
  public static final List<Integer> INT_LIST = io.vertx.codegen.testmodel.ConstantTCK.INT_LIST;
  public static final List<Long> LONG_LIST = io.vertx.codegen.testmodel.ConstantTCK.LONG_LIST;
  public static final List<Float> FLOAT_LIST = io.vertx.codegen.testmodel.ConstantTCK.FLOAT_LIST;
  public static final List<Double> DOUBLE_LIST = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE_LIST;
  public static final List<Boolean> BOOLEAN_LIST = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN_LIST;
  public static final List<Character> CHAR_LIST = io.vertx.codegen.testmodel.ConstantTCK.CHAR_LIST;
  public static final List<String> STRING_LIST = io.vertx.codegen.testmodel.ConstantTCK.STRING_LIST;
  public static final List<io.vertx.rxjava.codegen.testmodel.RefedInterface1> VERTX_GEN_LIST = io.vertx.codegen.testmodel.ConstantTCK.VERTX_GEN_LIST.stream().map(elt -> io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)elt)).collect(Collectors.toList());
  public static final List<JsonObject> JSON_OBJECT_LIST = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT_LIST;
  public static final List<JsonArray> JSON_ARRAY_LIST = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY_LIST;
  public static final List<io.vertx.codegen.testmodel.TestDataObject> DATA_OBJECT_LIST = io.vertx.codegen.testmodel.ConstantTCK.DATA_OBJECT_LIST;
  public static final List<io.vertx.codegen.testmodel.TestEnum> ENUM_LIST = io.vertx.codegen.testmodel.ConstantTCK.ENUM_LIST;
  public static final Set<Byte> BYTE_SET = io.vertx.codegen.testmodel.ConstantTCK.BYTE_SET;
  public static final Set<Short> SHORT_SET = io.vertx.codegen.testmodel.ConstantTCK.SHORT_SET;
  public static final Set<Integer> INT_SET = io.vertx.codegen.testmodel.ConstantTCK.INT_SET;
  public static final Set<Long> LONG_SET = io.vertx.codegen.testmodel.ConstantTCK.LONG_SET;
  public static final Set<Float> FLOAT_SET = io.vertx.codegen.testmodel.ConstantTCK.FLOAT_SET;
  public static final Set<Double> DOUBLE_SET = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE_SET;
  public static final Set<Boolean> BOOLEAN_SET = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN_SET;
  public static final Set<Character> CHAR_SET = io.vertx.codegen.testmodel.ConstantTCK.CHAR_SET;
  public static final Set<String> STRING_SET = io.vertx.codegen.testmodel.ConstantTCK.STRING_SET;
  public static final Set<io.vertx.rxjava.codegen.testmodel.RefedInterface1> VERTX_GEN_SET = io.vertx.codegen.testmodel.ConstantTCK.VERTX_GEN_SET.stream().map(elt -> io.vertx.rxjava.codegen.testmodel.RefedInterface1.newInstance((io.vertx.codegen.testmodel.RefedInterface1)elt)).collect(Collectors.toSet());
  public static final Set<JsonObject> JSON_OBJECT_SET = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT_SET;
  public static final Set<JsonArray> JSON_ARRAY_SET = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY_SET;
  public static final Set<io.vertx.codegen.testmodel.TestDataObject> DATA_OBJECT_SET = io.vertx.codegen.testmodel.ConstantTCK.DATA_OBJECT_SET;
  public static final Set<io.vertx.codegen.testmodel.TestEnum> ENUM_SET = io.vertx.codegen.testmodel.ConstantTCK.ENUM_SET;
  public static final java.util.Map<String, Byte> BYTE_MAP = io.vertx.codegen.testmodel.ConstantTCK.BYTE_MAP;
  public static final java.util.Map<String, Short> SHORT_MAP = io.vertx.codegen.testmodel.ConstantTCK.SHORT_MAP;
  public static final java.util.Map<String, Integer> INT_MAP = io.vertx.codegen.testmodel.ConstantTCK.INT_MAP;
  public static final java.util.Map<String, Long> LONG_MAP = io.vertx.codegen.testmodel.ConstantTCK.LONG_MAP;
  public static final java.util.Map<String, Float> FLOAT_MAP = io.vertx.codegen.testmodel.ConstantTCK.FLOAT_MAP;
  public static final java.util.Map<String, Double> DOUBLE_MAP = io.vertx.codegen.testmodel.ConstantTCK.DOUBLE_MAP;
  public static final java.util.Map<String, Boolean> BOOLEAN_MAP = io.vertx.codegen.testmodel.ConstantTCK.BOOLEAN_MAP;
  public static final java.util.Map<String, Character> CHAR_MAP = io.vertx.codegen.testmodel.ConstantTCK.CHAR_MAP;
  public static final java.util.Map<String, String> STRING_MAP = io.vertx.codegen.testmodel.ConstantTCK.STRING_MAP;
  public static final java.util.Map<String, JsonObject> JSON_OBJECT_MAP = io.vertx.codegen.testmodel.ConstantTCK.JSON_OBJECT_MAP;
  public static final java.util.Map<String, JsonArray> JSON_ARRAY_MAP = io.vertx.codegen.testmodel.ConstantTCK.JSON_ARRAY_MAP;
  public static ConstantTCK newInstance(io.vertx.codegen.testmodel.ConstantTCK arg) {
    return arg != null ? new ConstantTCK(arg) : null;
  }

}
